% Analyzing picked dispersion curves, interpolating at desired periods and
% building MCTomo input files

% Preparing MCTomo input files....
clc;clear;%close all
addpath('../datafiles')
addpath('Functions')
load('PickedPhaseVelocityCurves.mat')
load('station_info_utm.mat')
%% Model boundaries
Xmin=360e3;Xmax=480e3;
Ymin=7040e3;Ymax=7110e3;
freq2invert=1./([2:0.5:10]);
nwavelength2discard=1.5;
% Source receivers in model bounds
xrcv=xrcv+xmin;yrcv=yrcv+ymin;
%% Excluding source and receivers that are out of the bounds of the model
count=1;
index2rm=[];
for i=1:length(xrcv)
    if xrcv(i)<Xmin || xrcv(i)>Xmax || yrcv(i)<Ymin || yrcv(i)>Ymax
        index2rm(count)=i;count=count+1;
    end
end
xrcv=xrcv*1e-3;yrcv=yrcv*1e-3;
%% Checking picked curves to remove any pairs that are located outside of the model bounds
for i=length(PickedCurve):-1:1
    if length(index2rm)>=1
        if any(index2rm==PickedCurve{1,i}.nrcv) || any(index2rm==PickedCurve{1,i}.nsrc)
            PickedCurve(i)=[];
        end
    end
end
%% resampling phase velocities at predefined periods (frequencies)
fmax=0.6;
k=1;
nrays=0;nactiverays=0;npairs=1;
Information=zeros(size(PickedCurve,2),length(freq2invert)+2);
TT=zeros(length(PickedCurve),length(freq2invert));
DCs1=zeros(length(PickedCurve),length(freq2invert));
DCs=DCs1;
for i=1:length(xrcv)%receivers
    for j=1:length(xrcv)% sources
        if PickedCurve{1,k}.nrcv==i% receivernumber i is active
            if PickedCurve{1,k}.nsrc==j% source number j is active
                [DCs1(npairs,:),TT(npairs,:)]=ResamplingDCs(PickedCurve{1,k},freq2invert,fmax,nwavelength2discard);
                i2invert=find(TT(npairs,:)>0);
                DCs(npairs,i2invert)=DCs1(npairs,i2invert);
                Information(npairs,1:2)=[i,j];
                Information(npairs,2+i2invert)=1;
                npairs=npairs+1;
                if k<length(PickedCurve)
                    k=k+1;
                end
            end
        end
        
    end
    disp(i);
end
DCs(npairs+1:end,:)=[];
Information(npairs+1:end,:)=[];
DCs=DCs/1000;
DCs_bkup=DCs;
% DCs=DCs_bkup;
%% computing average and standard deviation at each frequency
DCs_mean=zeros(1,length(freq2invert));
DCs_std=zeros(1,length(freq2invert));

for j=1:size(DCs,2)
    iavailable=find(DCs(:,j)>0);
    DCs_mean(j)=mean(DCs(iavailable,j));
    DCs_std(j)=std(DCs(iavailable,j));
end
%% Removing outliers
n=2;% Following Schippkus et al 2018, I remove data outside two standard deviations as the outliers.

figure('Position',get(0,'screensize'));
subplot(221)
i=1;
j2plot=find(DCs(i,:)>0);
plot(freq2invert(j2plot),DCs(i,j2plot),':b')
plot(freq2invert,DCs_mean,'k',freq2invert,DCs_mean+2*DCs_std,'g',freq2invert,DCs_mean+3*DCs_std,'r','LineWidth',3)
hold on;
for i=2:size(DCs,1)
    j2plot=find(DCs(i,:)>0);
    plot(freq2invert(j2plot),DCs(i,j2plot),':b')
end
plot(freq2invert,DCs_mean,'k',freq2invert,DCs_mean+2*DCs_std,'g',freq2invert,DCs_mean+3*DCs_std,'r','LineWidth',4)
plot(freq2invert,DCs_mean,'k',freq2invert,DCs_mean-2*DCs_std,'g',freq2invert,DCs_mean-3*DCs_std,'r','LineWidth',4)

% plot(freq2invert,DCs_mean,'k',freq2invert,DCs_mean+n*DCs_std,'g',freq2invert,DCs_mean-n*DCs_std,'g','LineWidth',4)
legend('DCs','\mu','\mu\pm 2\sigma','\mu\pm 3\sigma')
xlabel('Frequency (Hz)');ylabel('km/s')
title('(a)')
set(gca,'Fontsize',16,'FontWeight','bold')
%% Find non active rays: this to store information for finding the removed
%rays as outliers
nonactiverays=find(DCs_bkup<=0);
% Removing outliers
DCs2=DCs;
for j=1:size(DCs,2)
    i2remove=find(DCs(:,j)<(DCs_mean(j)-n*DCs_std(j)));
    DCs(i2remove,j)=0;
    DCs2(i2remove,j)=-999;
    i2remove=find(DCs(:,j)>(DCs_mean(j)+n*DCs_std(j)));
    DCs(i2remove,j)=0;
    DCs2(i2remove,j)=-999;
end
DCs2(nonactiverays)=0;
% Removing bad rays, those on the eadge of the model that are meant to be
% the reason for high or low velocities
ibadrays=size(Information,1)+1-[1,3,7,13,23,803];%[1,3,7,13,23,62,74,803];
DCs(ibadrays,:)=0;
DCs2(ibadrays,:)=0;
% figure('Position',get(0,'screensize'));
% plot(xrcv,yrcv,'Marker','x','LineStyle','none','MarkerSize',10)
% hold on;
% for i=1:length(ibadrays)
%     plot(xrcv(Information(ibadrays(i),1:2)),yrcv(Information(ibadrays(i),1:2)))
%     title(num2str(i))
%     pause(1)
% end
subplot(222);hold off
% plot(freq2invert,DCs_mean,'k',freq2invert,DCs_mean+n*DCs_std,'g',freq2invert,DCs_mean-n*DCs_std,'g','LineWidth',3)
hold on;
for i=1:size(DCs,1)
    j2plot=find(DCs(i,1:length(freq2invert))>0);
    if length(j2plot)>=5
        % plot(freq2invert(j2plot),DCs(i,j2plot),':b')
    elseif length(j2plot)>=1 && length(j2plot)<5
        DCs(i,j2plot)=0;
        DCs2(i,j2plot)=-999;
    else
        DCs(i,j2plot)=0;
    end
end
% plot(freq2invert,DCs_mean,'k',freq2invert,DCs_mean+n*DCs_std,'g',freq2invert,DCs_mean-n*DCs_std,'g','LineWidth',4)
% legend('\mu','\mu+2\sigma','\mu-2\sigma','Dcs')
% xlabel('Frequency (Hz)');ylabel('km/s')
% xlim([0.1 0.5]);ylim([1.500 4.000])
% set(gca,'Fontsize',16,'FontWeight','bold')
% hold off;
% finding number of active rays at each frequency
for j=1:size(DCs,2)
    activerays(j)=nnz(DCs(:,j));
end
yyaxis left
bar(1./freq2invert,activerays(1:length(freq2invert)))
ylabel('Number of active rays')
% the most sensitive depths
landa=DCs_mean./freq2invert;
most_sensitive_depth=landa/3;
yyaxis right
stem(1./freq2invert,most_sensitive_depth,'LineWidth',3)
ylabel('Most sensitive depth (km)')

title('(b)')
xlabel('Periods (s)');
set(gca,'Fontsize',16,'FontWeight','bold')
%% ploting raypaths-phase velocity
Information2=Information;
Information2(:,3:end)=DCs;
load('station_info_Reykjanes.mat')
subplot(223);
RaysVelsPlot(LatLong(:,1),LatLong(:,2),4,Information2);
title('(c)')
subplot(224);hold off
RaysVelsPlot(LatLong(:,1),LatLong(:,2),10,Information2);
title('(d)')
%%
exportgraphics(gcf,'Figure3.png')
saveas(gcf,'Figure3.fig')

%% plotting outlier rays
% finding removed rays as outliers
outlier_rays=find(DCs2==-999);
DCs3=0*DCs2;
DCs3(outlier_rays)=DCs_bkup(outlier_rays);
for j=1:size(DCs3,2)
    activerays3(j)=nnz(DCs3(:,j));
end
%% 
figure('Position',get(0,'screensize'));
Information3=Information;
Information3(:,3:end)=DCs3;
load('station_info_Reykjanes.mat')
n1=4;n2=10;
subplot(221);
RaysVelsPlot(LatLong(:,1),LatLong(:,2),n1,Information2);
title('(a)')
subplot(222);hold off
RaysVelsPlot(LatLong(:,1),LatLong(:,2),n2,Information2);
title('(b)')
subplot(223);
RaysVelsPlot(LatLong(:,1),LatLong(:,2),n1,Information3);
title('(c)')
subplot(224);hold off
RaysVelsPlot(LatLong(:,1),LatLong(:,2),n2,Information3);
title('(d)')
exportgraphics(gcf,'FigureS1.png')
saveas(gcf,'FigureS1.fig')