clc;clear;close all
addpath('../datafiles')
addpath('Functions')
load('CCsTD_Figure3.mat')
% load('DC_picking4manuscript.mat')
fg1=figure('Position',get(0,'screensize'));
fg2=figure('Position',get(0,'screensize'));
for i=1:3
    DIST=data((i)).DIST;
    taxis=data((i)).taxis;
    CCsTDi=data((i)).CCsTD;
    %% Computing cross-spectrum of the time-averaged cross correlation
    CCsFDi=(fft(fftshift(CCsTDi),length(CCsTDi)))/length(CCsTDi);% FFT of a two-sided signal, FFT needs to get a signal with zero time at the begining of the signal; that is why we applied an fftshift before applying fft function
    %% obtaining the frequency axis using the time axis information
    dt=taxis(2)-taxis(1);% time sampling spacing
    time=taxis(end)-taxis(1);% Total time of the input signal
    fnyq=1/2/dt;% maximum frequency which is Nyquist frequency
    df=1/time;% frequency sampling spacing
    frequency=0:df:fnyq;% positive side of the frequency axis
    realpart=real(CCsFDi(1:length(frequency)));% the real part of the cross-spectrum for the positive frequencies; from zero to Nyquist frequency
    %% setting the valid range of frequencies and velocities
    minv=0.500;maxv=5.500;% Minimum and maximum velocity range to search in for phase velocities
    fmin=0.07;fmax=0.7;% Frequency limits to compute zero-crossings, it is recommended to consider a range wider than your desired picking limits which will be used in next section
    maxf=0.55;minf=0.1;%Picking limits
    % Defining display limits, only for the purpose of illustration but not computation
    pvdisplaylimit=[1.5 5];% Phase velocity display limit
    fdisplaylim=[fmin maxf];% Frequency display limit
    timedisplaylim=[-150 150];
    %% Find zero crossings
    % when the data contains noise we have to smooth the real part to reduce the noise effects
    % p is an important parameter and affects the results too much, so be carefull and set a proper value for it
    p=0.9999999;% smoothing level: p=0 gives a line and p=1 means no smoothing
    [faxis,velocities,faxis_realpart_fine,realpart_fine,xr]=Find_Zero_Crossings(fmin,fmax,frequency,realpart,DIST,minv,maxv,p);
    %% Picking phase velocities
    % Defining picking parameters
    % Parameters that might be changed based on data
    maxf=0.55;minf=0.09;%Picking limits
    maxf2pick=0.55;
    % minv=1.00;maxv=5.500;%km/s
    freq2invert=1./(2:0.5:10);% Frequencies to be used for the inversion
    nwavelength2discard=1;
    mes=sprintf(' p = pick \n d = delet every pick in the right side of the selected point \n r = remove the selected point \n a = pick again by considering the selected point as the starting point \n s = skip/ignore this pair because of poor quality \n q = finished \n x = exit picking and save picked curves');
    disp([sprintf('Picking short keys: \n'),mes])
    figure(fg2);
    subplot(5,1,3:5);
    % fdisplaylim=[fmin fmax];
    % pvdisplaylimit=[minv maxv];
    PickedCurve{i}=PhaseVelocityPicking(velocities,faxis,maxf,minf,DIST,freq2invert,nwavelength2discard,fdisplaylim,pvdisplaylimit); % maxf2pick

    %% plotting real part and computed zero crossings
    figure(fg1);
    subplot(5,3,i);
    plot(taxis,CCsTDi,'k','LineWidth',3);xlim(timedisplaylim);xlabel('Time (s)');ylabel('Amplitude');set(gca,'LineWidth',2,'FontWeight','bold','FontSize',16);
    title(['Interstation distance: ',num2str(DIST),' km'])
    subplot(5,3,i+3);
    hold off;
    plot(faxis_realpart_fine,realpart_fine,'k','LineWidth',2);hold on
    hold on;plot(xr,zeros(size(xr)),'r*','LineWidth',2);
    xlim(fdisplaylim)
    xlabel('Frequency (Hz)');%title('(a) Real part of the Fourier transformed wavefield')
    ylabel('Amplitude');
    set(gca,'LineWidth',2,'FontWeight','bold','FontSize',16);
    figure(gcf);subplot(5,3,[6,9,12]+i);
    plot(faxis,velocities,'bo','LineWidth',2,'MarkerSize',10);
    ylim(pvdisplaylimit);xlim(fdisplaylim)
    xlabel('Frequency (Hz)');ylabel('Phase velocity (km/s)')
    set(gca,'LineWidth',2,'FontWeight','bold','FontSize',16);
    reference_curve=dlmread('disp_PREM300.data');
    ref_freq_i=reference_curve(:,1);
    ref_vel_i=1./reference_curve(:,2)/1000;%km/s
    figure(gcf);subplot(5,3,[6,9,12]+i);hold off;
    plot(faxis,velocities,'bo','linewidth',2,'MarkerSize',10);
    hold on;plot(ref_freq_i,ref_vel_i,'y','linewidth',3)
%% 
    hold on;plot(PickedCurve{(i)}.discr_freqs,PickedCurve{(i)}.discr_vels,'k*','linewidth',3)
%% 
    pv2inverti=PickedCurve{(i)}.pv2invert;
    index1=find(pv2inverti>0);
    [fitresult_tt, gof] = createFit_fre_TT1(PickedCurve{(i)}.discr_freqs,PickedCurve{(i)}.discr_vels);
    fine_freq2plot_interpolation=freq2invert;%linspace(min(PickedCurve{(i)}.discr_freqs),max(PickedCurve{(i)}.discr_freqs),50);
    vv=fitresult_tt(fine_freq2plot_interpolation);
    hold on;plot(fine_freq2plot_interpolation,vv,'r','linewidth',2)
%% 
    hold on;plot(PickedCurve{(i)}.freq2invert,PickedCurve{(i)}.pv2invert,'g','linestyle','non','MarkerSize',14,'Marker','o','linewidth',4)
%%   
    vv2=fitresult_tt(PickedCurve{(i)}.freq2invert);
    hold on;plot(PickedCurve{(i)}.freq2invert,vv2,'r','linestyle','none','MarkerSize',10,'Marker','+','linewidth',3)
    legend('Candidate phase velocities','Reference curve','Picked points','Interpolation result','Points to be used in inversion');
    set(gca,'LineWidth',2,'FontWeight','bold','FontSize',16);
    xlabel('Frequency (Hz)','FontSize',14,'FontWeight','bold')
    ylabel('Phase velocity (km/s)','FontSize',14,'FontWeight','bold')
    xlim(fdisplaylim);
    ylim(pvdisplaylimit)
    %     pause(2)
end
subplot(531);ylim([-500 700]);title('(a)');% Interstation distance: 25.1 km
subplot(532);ylim([-200 300]);title('(b)');% Interstation distance: 50 km
subplot(533);ylim([-100 150]);title('(c)');% Interstation distance: 99 km
subplot(534);ylim([-1 1.50])
subplot(535);ylim([-0.5 0.80])
subplot(536);ylim([-0.5 0.70])

exportgraphics(gcf,'FigureA1.png')
saveas(gcf,'FigureA1.fig')
